@@ -13,16 +13,32 @@
 # pylint:disable=missing-module-docstring
 import logging
 from functools import lru_cache
+from importlib.util import find_spec
+from sys import modules
 from typing import (
     Any,
     List,
     Union,
 )
+from warnings import warn
 
 import inflection
 from gql import Client
 from graphql import GraphQLType
-from tqdm.auto import tqdm
+
+# pylint: disable=wrong-import-position
+# Do not use `tqdm.auto` if the user is running Jupyter (IPython is loaded)
+# but ipywidgets is not available (its spec is None or its `has_location` is False).
+# For more info, see: https://github.com/tqdm/tqdm/pull/1218
+ipywidgets_spec = find_spec("ipywidgets")
+if ("IPython" in modules) and (
+    (ipywidgets_spec is None) or (not ipywidgets_spec.has_location)
+):
+    warn("For a better progress bar experience on Jupyter, install `ipywidgets`.")
+    from tqdm.std import tqdm
+else:
+    from tqdm.auto import tqdm
+# pylint: enable=wrong-import-position
 
 from ..queries import (
     MultiRefreshActionQuery,
