@@ -33,21 +33,6 @@ FUNCTION_NAMESPACE_DOCSTRING = """
 """
 
 
-OPERATION_NAMESPACE_DOCSTRING = """
-    Namespace for operations. Operations are used to build graphs for
-    remote execution of complex computation.
-
-    The types in this namespace each represent the result of some remote
-    graph computation. As a result, you cannot directly access data from
-    the objects of these types (although where documented you can access
-    attributes of objects, which similarly correspond to results of remote
-    computations). Instead, you can represent complex computations by
-    feeding the objects output from one operation as the inputs to the
-    next, and you can fetch the final computed values of objects by
-    requesting them as outputs from the appropriate `functions`.
-"""
-
-
 TYPE_NAMESPACE_DOCSTRING = """
     Namespace for types. Objects created from these types are used
     when performing computations defined in the `functions` namespace.
@@ -86,7 +71,7 @@ class BaseNamespace(SimpleNamespace):
 
         Parameters
         ----------
-        funcs : Callable
+        *funcs : Callable
             functions to be added to the namespace.
 
         Returns
@@ -187,12 +172,6 @@ def create_function_namespace():
     return cls()
 
 
-def create_operation_namespace():
-    """Creates the operation namespace."""
-    cls = _create_namespace_cls("Operation", OPERATION_NAMESPACE_DOCSTRING)
-    return cls()
-
-
 def create_type_namespace():
     """Creates the type namespace."""
     cls = _create_namespace_cls(
@@ -204,6 +183,5 @@ def create_type_namespace():
 __all__ = [
     "BaseNamespace",
     "create_function_namespace",
-    "create_operation_namespace",
     "create_type_namespace",
 ]
