@@ -14,6 +14,7 @@
 import logging
 import os
 import sys
+import webbrowser
 from threading import Thread
 from typing import (
     Dict,
@@ -35,12 +36,18 @@ from requests.exceptions import (
 
 from .builders import (
     AsyncResult,
-    build_namespaces,
+    build_and_bind_namespaces,
     create_client_auth,
     create_environment,
     create_gql_client,
 )
-from .constants import DEFAULT_API_ROOT
+from .constants import (
+    BASE_URL,
+    DEFAULT_API_ROOT,
+    DEFAULT_OIDC_URL,
+    INVALID_SUBSCRIPTION_ERROR,
+    UNEXPECTED_TOKEN_ERROR,
+)
 from .graphs import Graph
 from .parallel import ParallelExecutionCollector
 from .queries import (
@@ -68,23 +75,26 @@ class Qctrl:
 
     .. code-block:: python
 
-      q = Qctrl()
+      qctrl = Qctrl()
 
-    If needed authentication can also be done by passing your email and password as arguments
-    to the Qctrl() function as shown below. Ensure that the credentials used are secure.
-
-    .. code-block:: python
-
-      q = Qctrl(email='myemail', password='mypassword')
+    .. deprecated:: 15.4.4
+          Email and password based authentication has been removed in favour of
+          url based authentication. To authenticate simply call `qctrl = Qctrl()`
+          without any additional arguments.
 
     Parameters
     ----------
     email : str, optional
-        The email address for a Q-CTRL account. (Default value = None)
+        The email address for a Q-CTRL account.
+        [This field has been deprecated] (Default value = None)
     password : str, optional
-        The password for a Q-CTRL account. (Default value = None)
+        The password for a Q-CTRL account. [This field has been deprecated] (Default value = None)
     api_root : str, optional
         The URL of the Q-CTRL API. (Default value = None)
+    oidc_url : str, optional
+        The URL of the Q-CTRL OIDC. (Default value = None)
+    env_namespace : str, optional
+        The environment namespace of the Q-CTRL stack. (Default value = None)
     skip_version_check: bool, optional
         Option for disabling the version check. (Default value = False)
     client : gql.Client, optional
@@ -98,8 +108,6 @@ class Qctrl:
     ----------
     functions : :ref:`qctrl.dynamic.namespaces.FunctionNamespace`
     types : :ref:`qctrl.dynamic.types`
-    operations
-        Deprecated, call methods on :py:obj:`~qctrl.graphs.Graph` instead.
 
     Raises
     ------
@@ -108,7 +116,6 @@ class Qctrl:
 
     gql_api = None
     functions = None
-    operations = None
     types = None
 
     def __init__(
@@ -116,54 +123,63 @@ class Qctrl:
         email: str = None,
         password: str = None,
         api_root: str = None,
+        oidc_url: str = None,
+        env_namespace: Optional[str] = None,
         skip_version_check: bool = False,
         client: Client = None,
     ):
         if not skip_version_check:
             self._check_version_thread()
 
+        if email or password:
+            error_message = (
+                "Q-CTRL Python package authentication has been updated."
+                " Please start a session without your credentials."
+            )
+            click.echo(error_message)
+            sys.exit(1)
+
         if client is None:
-            self.gql_api = _build_client(api_root, email, password)
+            api_root = api_root or os.environ.get("QCTRL_API_HOST") or DEFAULT_API_ROOT
+            oidc_url = oidc_url or os.environ.get("QCTRL_OIDC_URL") or DEFAULT_OIDC_URL
+
+            env_namespace = env_namespace or os.environ.get("QCTRL_ENV_NAMESPACE")
+            if env_namespace:
+                api_root = BASE_URL.format(f"{env_namespace}.api")
+                oidc_url = BASE_URL.format(f"{env_namespace}.id")
+
+            self.gql_api = _build_client(api_root=api_root, oidc_url=oidc_url)
         else:
-            if email or password or api_root:
+            if env_namespace or oidc_url or api_root:
                 raise ValueError(
-                    "If you pass a client, do not pass an email, password, or API root."
+                    "If you pass a client, do not pass an env_namespace, oidc_url, or api_root."
                 )
             self.gql_api = client
 
         self.gql_env = create_environment(self.gql_api)
         self.collector: Optional[ParallelExecutionCollector] = None
-        self._build_namespaces()
+        self._build_and_bind_namespaces()
 
     @tenacity.retry(
         wait=tenacity.wait_exponential(multiplier=1, min=1, max=5),
         stop=tenacity.stop_after_attempt(3),
         retry=tenacity.retry_if_exception_type((RequestException, BaseHTTPError)),
     )
-    def _build_namespaces(self):
+    def _build_and_bind_namespaces(self):
         """Builds the dynamic namespaces."""
-        (
-            self.functions,
-            self.operations,
-            self.types,
-        ) = build_namespaces(self)
+        build_and_bind_namespaces(self)
 
     @staticmethod
-    def create_graph(name: str = None) -> Graph:
+    def create_graph() -> Graph:
         """
         Creates a graph object for representing remote computations.
 
-        Parameters
-        ----------
-        name : deprecated
-            This parameter will be removed in the future.
-
         Returns
         -------
         Graph
             The new graph object.
         """
-        return Graph(name=name)
+        return Graph()
 
     def activity_monitor(
         self,
@@ -328,7 +344,8 @@ class Qctrl:
     retry=tenacity.retry_if_exception_type((RequestException, BaseHTTPError)),
 )
 def _build_client(
-    api_root: str = None, email: str = None, password: str = None
+    api_root: str,
+    oidc_url: str,
 ) -> Client:
     """
     Builds an authenticated GraphQL client and validates its authentication.
@@ -337,21 +354,17 @@ def _build_client(
     ----------
     api_root: str
         API root (Default value = None)
-    email: str
-        user email (Default value = None)
-    password: str
-        user password (Default value = None)
+    oidc_url: str
+        OIDC url (Default value = None)
 
     Returns
     -------
     GraphQLClient
         gql client.
     """
-    api_root = api_root or os.environ.get("QCTRL_API_HOST") or DEFAULT_API_ROOT
-    assert api_root
 
     try:
-        auth = create_client_auth(api_root, email, password)
+        auth = create_client_auth(oidc_url)
         client = create_gql_client(api_root, auth)
         MeQuery(client)()
 
@@ -359,19 +372,14 @@ def _build_client(
         LOGGER.info(error, exc_info=error)
 
         if "token" in str(error):
-            description = """
----------------------------------------------------------------------
-An error occurred with your session authentication. Please try again.
-If the issue persists, recreate your environment authentication by
-running `qctrl auth` from the command line.
+            click.echo(UNEXPECTED_TOKEN_ERROR, err=True)
+            sys.exit(1)
 
-For non-interactive or alternative options check our help:
+        if "invalid subscription" in str(error):
+            if "api." in api_root:
+                webbrowser.open(api_root.replace("api.", "boulder."))
 
-    $ qctrl auth --help
-
----------------------------------------------------------------------
-"""
-            click.echo(description, err=True)
+            click.echo(INVALID_SUBSCRIPTION_ERROR, err=True)
             sys.exit(1)
 
         sys.exit(error)
