@@ -15,6 +15,7 @@ import logging
 import re
 from functools import wraps
 from typing import (
+    Any,
     Callable,
     Optional,
     Union,
@@ -36,6 +37,7 @@ from requests import codes
 from requests.exceptions import HTTPError
 
 from qctrl import __version__
+from qctrl.constants import UNIVERSAL_ERROR_MESSAGE
 
 LOGGER = logging.getLogger(__name__)
 
@@ -274,3 +276,20 @@ def _get_mutation_result_type(schema: GraphQLSchema, mutation_name: str) -> Grap
         raise KeyError(f"unknown mutation: {mutation_name}") from error
 
     return mutation_field.type
+
+
+def error_handler(func: Callable) -> Any:
+    """
+    Catch all exception and return a generic error message with
+    cause of exception.
+    """
+
+    @wraps(func)
+    def wrapper(*args, **kwargs):
+        try:
+            return func(*args, **kwargs)
+        except Exception as exc:
+            LOGGER.error(exc)
+            raise QctrlException(UNIVERSAL_ERROR_MESSAGE) from exc
+
+    return wrapper
